#
# spec file for package minicom
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           minicom
Version:        2.7.1
Release:        lp152.3.6
Summary:        A Terminal Program
License:        GPL-2.0+
Group:          Hardware/Modem
Url:            http://alioth.debian.org/projects/minicom/
Source0:        https://alioth.debian.org/frs/download.php/latestfile/3/%{name}-%{version}.tar.gz
Patch0:         minicom-2.2-defaults.diff
Patch2:         03norzsz.diff
Patch4:         minicom-2.3-no-build-date.patch
Patch5:         minicom-2.4-norootsetup.diff
# PATCH-FIX-UPSTREAM increase permitted length of serial device (bnc#707860)
Patch6:         minicom-2.5-serial_device_path_length.patch
BuildRequires:  ckermit
BuildRequires:  gettext-devel
BuildRequires:  lockdev-devel
BuildRequires:  ncurses-devel
BuildRequires:  pkg-config
Requires:       ckermit
Requires:       rzsz
Requires(pre):  group(uucp)
Recommends:     %{name}-lang
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
A terminal program similar to Telix(tm) (a program for calling other
computers via modem) under MS-DOS.

If you want to access your modem with minicom, you have to be a member
of the uucp group.

%lang_package

%prep
%setup -q
%patch0
%patch2 -p1
%patch4
%patch5 -p1
%patch6 -p1

%build
export CFLAGS="%{optflags} $(ncursesw6-config --cflags)"
export LDFLAGS="$(ncursesw6-config --libs)"
%configure \
    --disable-rpath \
    --enable-music \
    --enable-dfl-baud=57600 \
    --enable-dfl-port=/dev/modem \
    --enable-socket \
    --enable-cfg-dir=%{_sysconfdir}
make %{?_smp_mflags}

%install
make DESTDIR=%{buildroot} install %{?_smp_mflags}
%find_lang %{name}

%files
%defattr(644,root,root,755)
%doc doc/minicom.FAQ AUTHORS COPYING NEWS README
%attr(0755,root,root) %{_bindir}/ascii-xfr
%attr(0755,root,uucp) %{_bindir}/minicom
%attr(0755,root,root) %{_bindir}/runscript
%attr(0755,root,root) %{_bindir}/xminicom
%{_mandir}/man1/ascii-xfr.1.gz
%{_mandir}/man1/minicom.1.gz
%{_mandir}/man1/xminicom.1.gz
%{_mandir}/man1/runscript.1.gz

%files lang -f %{name}.lang
%defattr(-,root,root)

%changelog
* Thu Apr 13 2017 sflees@suse.de
- Update to 2.7.1
  * Contains 1 fix for CVE-2017-7467, bsc#1033783
  * Invalid cursor coordinates and scroll regions could lead to code
    execution
* Wed Oct 26 2016 kukuk@suse.de
- Add PreReq for group uucp
* Fri Mar 13 2015 tchvatal@suse.com
- Split language to subpackage
- Remove check phase, it is empty just saying there is nothing to be done
- Use name and version macros in Source path
* Tue Jan 14 2014 dmueller@suse.com
- fix Source url
* Thu Jan  2 2014 vcizek@suse.com
- update to 2.7
  * Configurable status line via -F option, see manpage for a listing
    of format specifier.
  * Improve display of device name in status line.
  * Script: Binary transmission feature via "!<"
  * Fixes.
* Wed Dec 18 2013 mvyskocil@suse.com
- update to 2.6.2
  * Alternative hex output (to be improved)
  * Print creation date of serial device file (if < 20 hrs), useful for
  identifying just plugged in USB-Serial adapters
  * Support ':' (colon) in device path names. Note, that this changes old
  behaviour which used ':' as a device path delimiter.
  * Several language updates.
- refreshed/rebased patches
  * minicom-2.3-no-build-date.patch
  * minicom-2.4-norootsetup.diff
  * minicom-2.5-serial_device_path_length.patch
* Fri Dec 28 2012 crrodriguez@opensuse.org
- configure wants "ckermit" present during build and at runtime.
- Prefer ncurses6w.
* Wed May 30 2012 sweet_f_a@gmx.de
- remove not needed minicom-2.3-ncurses.patch to get rid of
  automake dependency
- update to 2.6.1
  * src/main.c, src/minicom.c: iconv: Handle the case that iconv
    did not convert anything. Reported by Mike Crowe, Debian #659351.
  * src/main.c: ETIME -> ETIMEDOUT as ETIME is not available on BSDs
  * src/main.c: Fix invalid memory used, reported by Larry Baker
* Tue May 29 2012 puzel@suse.com
- fix build with automake-1.12
  - add: automake-1.12.patch
* Mon Jan  2 2012 vcizek@suse.cz
- update to 2.6
  * Add possibility to add delay after every character transmission.
  * Fix build issues on Mac OS X.
  * Stop providing default modem init and reset strings (still available when
    editing).
  * Added possibility for timestamps in output, added by minicom
  * Added lockdev support.
  * Added new dialdir format that is supposed to be interoperable between 32
    and 64 bits archs.
* Thu Dec  1 2011 coolo@suse.com
- add automake as buildrequire to avoid implicit dependency
* Tue Oct 18 2011 vcizek@suse.com
- a complete fix for (bnc#707860)
* Wed Aug 24 2011 lnussel@suse.de
- fix lockdev suppport (bnc#713330)
* Tue Jul 26 2011 vcizek@novell.com
- increased length of serial device (bnc#707860)
* Mon Jan 31 2011 vcizek@novell.com
- update to 2.5
  * src/script.c: Make word handling more dynamic, and thus allowing
    words > 89 chars. Reported via Debian BTS #610511.
  * src/rwconf.c: Fix config file parsing bug, Thanks Jan Görig,
    https://bugzilla.redhat.com/show_bug.cgi?id=669406
  * src/updown.c: Check for error conditions on fd of running script.
    for minicom bug-tracker #312517, by Chris Simmonds
  * src/updown.c: Removed static buffers that limit multi-file
    zmodem functionality. (Redhat #98654)
- removed two unneeded patches
* Tue Jan 11 2011 lnussel@suse.de
- enable and fix socket support (bnc#661749)
- change default device to /dev/modem as /dev/tty8 doesn't make sense
- save to home if running as non-root
* Tue Aug 31 2010 anicka@suse.cz
- update to 2.4
  * Add options -b, -D and -R.
  * Remove environment variable for the remote
  charset and make it available via option -R.
  * remove all code that deals with running as suid-root. Also
  remove minicom.users as it's not needed anymore. Handle
  permissions within the file-system.
  * Consolidate lockfile handling into separate functions and use them,
  also do lockfile handling before and after launching kermit.
  * Add -b %%b (Baudrate) to kermit command call.
* Sun Aug 29 2010 cristian.rodriguez@opensuse.org
- Do not hardcode build dates in binaries
* Mon Jun 28 2010 jengelh@medozas.de
- use %%_smp_mflags
* Wed Apr 28 2010 lnussel@suse.de
- remove 01manual.diff as it's Debian specific
* Tue Mar  9 2010 lnussel@suse.de
- use lockdev (FATE#308360)
* Wed Dec 16 2009 crrodriguez@opensuse.org
- take over the package
- Import patches from Ubuntu
* Thu Aug 28 2008 ro@suse.de
- add ncurses include to cflags
* Tue Jul 22 2008 crrodriguez@suse.de
- fix build
* Mon Jun  9 2008 mmarek@suse.cz
- xminicom: display "minicom" in window title (bnc#398423)
* Fri Mar 28 2008 mmarek@suse.cz
- updated to 2.3
  * New version of the dial format to be little and big endian as
    well as 32/64 bit safe
  * Support more baud rates
  * Handle device disappearances (e.g. serial-USB device unplug)
  * Various build and other fixes
- specfile cleanup
* Thu Mar 29 2007 ro@suse.de
- added ncurses-devel to buildreq
* Thu Oct 19 2006 mjancar@suse.cz
- update to 2.2
  * Vietnamese translation added
  * Norwegian translation added
  * Traditional chinese translation added
  * Swedish translation added
  * Romanian translation added
  * default to 8bit mode if LANG or LC_ALL are set
  * default baud rate set to 115200
  * Various code cleanups and fixes
* Thu Aug 24 2006 mkoenig@suse.de
- reverted last change (moving scripts from aux/)
- changed gettext issues to fix build
* Tue Aug 22 2006 mkoenig@suse.de
- fixed getline name collision
- moved autotools scripts out of aux/
* Mon Feb 27 2006 anicka@suse.cz
- fix subscript out of range (#151489)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Apr 18 2005 mcihar@suse.cz
- fix for current gcc
* Fri Feb  4 2005 mcihar@suse.cz
- fixed permissions (bug #50438)
* Mon Jan 12 2004 adrian@suse.de
- add missing %%attr
* Sat Jan 10 2004 adrian@suse.de
- add %%defattr
* Wed Jul 23 2003 coolo@suse.de
- use BuildRoot and %%find_lang
- package xminicom man page
* Mon May 26 2003 stepan@suse.de
- update to 2.1
* Tue Dec 24 2002 mfabian@suse.de
- fix charset headers in Japanese .po files (messages in
  ja_JP.UTF-8 were garbled because of this)
- remove backslashes in the SJIS encoded Japanese .po file which were
  only needed as a workaround for deficiencies in older versions
  of gettext. These extra backslashes cause trouble with newer
  gettext versions.
* Fri Nov 29 2002 okir@suse.de
- add support for resmgr
* Mon Nov 18 2002 schwab@suse.de
- Add AM_GNU_GETTEXT_VERSION.
* Tue Oct  1 2002 uli@suse.de
- turned off HW flow control in default setup (bug #20390)
* Tue Sep 17 2002 ro@suse.de
- removed bogus self-provides
* Thu Apr  4 2002 ro@suse.de
- build with current automake/autoconf/gettext
* Thu Dec  6 2001 uli@suse.de
- update -> 2.00.0 (fixes, mainly)
* Thu Apr 19 2001 mfabian@suse.de
- fix invalid multibyte characters in ko.po just to make it build
* Wed Feb  7 2001 uli@suse.de
- fixed for glibc 2.2.1
* Thu Dec 21 2000 uli@suse.de
- replaced call of "sx" with "sz -X"
* Thu Nov 30 2000 uli@suse.de
- fixed some links
* Wed Nov 29 2000 uli@suse.de
- update -> 1.83.1
* Wed May 24 2000 uli@suse.de
- moved docs to /usr/share
* Thu Mar  2 2000 kukuk@suse.de
- Use _mandir macro
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Thu May  6 1999 kukuk@suse.de
- Don't link against libintl.a
* Thu Jul 30 1998 bs@suse.de
- don't start rz with "-E" by default - our rz does not know it.
* Tue Jul 28 1998 bs@suse.de
- marked minicom.users as %%config again.
* Mon Jul 27 1998 werner@suse.de
- new version 1.81.1
- applied red hat security patches
- DONT set sguid uucp (you can't be saver :) ).  User have to be in
  group uucp, if they want access to modem.
